numkit — Numerical analysis toolkit — GromacsWrapper 0.4.0-dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- GromacsWrapper 0.4.0-dev documentation »
- Auxiliary modules »

# `numkit` — Numerical analysis toolkit

A collection of functions and classes built on top of NumPy and SciPy to aid the numerical analysis of data. It is geared towards the use of data coming from molecular simulations, namely time series. It is used in `gromacs.analysis` and `gromacs.fileformats`.

Please note that these functions are provided “as is” and no guarantee is given that they are accurate or free from error. Bug reports and test cases are very welcome. Please submit them through the Github Issue Tracker.

See also

Core functionality is based on SciPy (`scipy` module).

Contents:

- `numkit.fitting` — Fitting data
  - Example
  - Creating new fit functions
  - Functions and classes
- `numkit.timeseries` — Time series manipulation and analysis
  - Correlations
  - Coarse graining time series
  - Smoothing time series
- `numkit.integration` — Numerical integration of data
- `numkit.observables` — Observables as quantities with errors

### Navigation

- index
- modules |
- next |
- previous |
- GromacsWrapper 0.4.0-dev documentation »
- Auxiliary modules »